import { JSONCommentWriterBase } from './jsonCommentWriterBase';
import { IJSONComment } from './types';
interface ISelectorTreeNode {
    next?: {
        [key: string]: ISelectorTreeNode;
    };
    any?: ISelectorTreeNode;
    this?: IJSONComment[];
}
/**
 * A JSON comment writer which supports custom comments for fields specified by path.
 * Implemented using a tree structure.
 */
export declare class CustomCommentWriter extends JSONCommentWriterBase<ISelectorTreeNode> {
    protected readonly root: ISelectorTreeNode;
    private static ensureNextNode;
    /**
     * Define the comments to be shown above the specified fields.
     * @param selector A path of keys.
     * `undefined` can be used to match any other key not matched on that level.
     * An empty array matches the root object.
     * @param comments Comments to be shown when the selector matches.
     * @example
     * ['a', 'b', undefined, 'c'] -> 'comment1'
     * ['a', 'b', 'd'] -> 'comment2'
     * { a: { b: { c: { c: "This field will have comment1" }}}}
     * { a: { b: { d: "This field will have comment2" }}}
     */
    addComments(selector: (string | number | undefined)[], comments: IJSONComment[]): void;
    protected nextNode(prevNode: Readonly<ISelectorTreeNode>, key: string | number): Readonly<ISelectorTreeNode> | undefined;
    protected getComments(currentNode: Readonly<ISelectorTreeNode>): IJSONComment[];
}
export {};
