"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var jsonCommentWriterBase_1 = require("./jsonCommentWriterBase");
/**
 * A JSON comment writer which supports custom comments for fields specified by path.
 * Implemented using a tree structure.
 */
var CustomCommentWriter = /** @class */ (function (_super) {
    tslib_1.__extends(CustomCommentWriter, _super);
    function CustomCommentWriter() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.root = {}; // root.any is the real root
        return _this;
    }
    CustomCommentWriter.ensureNextNode = function (currNode, key) {
        if (key === undefined) {
            return currNode.any = currNode.any || {};
        }
        currNode.next = currNode.next || {};
        return currNode.next[key] = currNode.next[key] || {};
    };
    /**
     * Define the comments to be shown above the specified fields.
     * @param selector A path of keys.
     * `undefined` can be used to match any other key not matched on that level.
     * An empty array matches the root object.
     * @param comments Comments to be shown when the selector matches.
     * @example
     * ['a', 'b', undefined, 'c'] -> 'comment1'
     * ['a', 'b', 'd'] -> 'comment2'
     * { a: { b: { c: { c: "This field will have comment1" }}}}
     * { a: { b: { d: "This field will have comment2" }}}
     */
    CustomCommentWriter.prototype.addComments = function (selector, comments) {
        var currNode = this.root.any = this.root.any || {};
        for (var _i = 0, selector_1 = selector; _i < selector_1.length; _i++) {
            var key = selector_1[_i];
            currNode = CustomCommentWriter.ensureNextNode(currNode, key);
        }
        currNode.this = currNode.this || [];
        currNode.this = currNode.this.concat(comments);
    };
    CustomCommentWriter.prototype.nextNode = function (prevNode, key) {
        if (prevNode.next && prevNode.next[key]) {
            return prevNode.next[key];
        }
        return prevNode.any;
    };
    CustomCommentWriter.prototype.getComments = function (currentNode) {
        return currentNode.this || [];
    };
    return CustomCommentWriter;
}(jsonCommentWriterBase_1.JSONCommentWriterBase));
exports.CustomCommentWriter = CustomCommentWriter;
//# sourceMappingURL=customCommentWriter.js.map