import { JSONCommentWriterBase } from './jsonCommentWriterBase';
import { IJSONComment, IJSONCommentConfiguration, JSONSchema } from './types';
export declare type CommentGenerator = (schema: JSONSchema) => IJSONComment | undefined;
/**
 * A JSON comment writer generating comments for fields specified in JSON schema.
 */
export declare class SchemaMetadataWriter extends JSONCommentWriterBase<JSONSchema> {
    private commentGenerator;
    protected readonly root: JSONSchema;
    /**
     * Construct a new SchemaMetadataWriter.
     * @param schemaObject A fully dereferenced JSON schema object
     *  containing no `$ref`, which can be obtained using libraries like
     *  `json-schema-ref-parser`.`dereference` with `circular` being true.
     * This object is allowed to be recursive.
     * @param commentGenerator A function to generate comment string
     *  from the schema of a field.
     * @param configuration Styling configuration for comments.
     */
    constructor(schemaObject: JSONSchema, commentGenerator?: CommentGenerator, configuration?: Partial<IJSONCommentConfiguration>);
    protected nextNode(currentNode: Readonly<JSONSchema>, key: string | number): Readonly<JSONSchema> | undefined;
    protected getComments(currentNode: Readonly<JSONSchema>): IJSONComment[];
}
