"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var defaultCommentGenerator_1 = require("./defaultCommentGenerator");
var jsonCommentWriterBase_1 = require("./jsonCommentWriterBase");
function hasProp(obj, key) {
    return Object.prototype.hasOwnProperty.call(obj, key);
}
/**
 * A JSON comment writer generating comments for fields specified in JSON schema.
 */
var SchemaMetadataWriter = /** @class */ (function (_super) {
    tslib_1.__extends(SchemaMetadataWriter, _super);
    /**
     * Construct a new SchemaMetadataWriter.
     * @param schemaObject A fully dereferenced JSON schema object
     *  containing no `$ref`, which can be obtained using libraries like
     *  `json-schema-ref-parser`.`dereference` with `circular` being true.
     * This object is allowed to be recursive.
     * @param commentGenerator A function to generate comment string
     *  from the schema of a field.
     * @param configuration Styling configuration for comments.
     */
    function SchemaMetadataWriter(schemaObject, commentGenerator, configuration) {
        if (commentGenerator === void 0) { commentGenerator = defaultCommentGenerator_1.defaultCommentGenerator; }
        var _this = _super.call(this, configuration) || this;
        _this.commentGenerator = commentGenerator;
        _this.root = { additionalProperties: schemaObject };
        return _this;
    }
    SchemaMetadataWriter.prototype.nextNode = function (currentNode, key) {
        if (typeof currentNode.properties === 'object') {
            if (hasProp(currentNode.properties, key)) {
                var next = currentNode.properties[key];
                if (typeof next === 'object') {
                    return next;
                }
            }
        }
        else if (currentNode.items) {
            if (Array.isArray(currentNode.items)) {
                if (key >= 0 && key < currentNode.items.length) {
                    var next = currentNode.items[key];
                    if (typeof next === 'object') {
                        return next;
                    }
                }
                else if (typeof currentNode.additionalItems === 'object') {
                    return currentNode.additionalItems;
                }
            }
            else if (typeof currentNode.items === 'object') {
                return currentNode.items;
            }
        }
        if (typeof currentNode.additionalProperties === 'object') {
            return currentNode.additionalProperties;
        }
        return undefined;
    };
    SchemaMetadataWriter.prototype.getComments = function (currentNode) {
        var comment = this.commentGenerator(currentNode);
        if (comment) {
            return [comment];
        }
        return [];
    };
    return SchemaMetadataWriter;
}(jsonCommentWriterBase_1.JSONCommentWriterBase));
exports.SchemaMetadataWriter = SchemaMetadataWriter;
//# sourceMappingURL=schemaMetadataWriter.js.map